@@ -5,8 +5,9 @@ from fastapi_amis_admin.amis.components import ColumnImage, InputImage
 from fastapi_amis_admin.models.fields import Field
 from fastapi_amis_admin.utils.translation import i18n as _
 from pydantic import EmailStr, SecretStr
-from sqlalchemy import Column, String, and_
+from sqlalchemy import and_, func
 from sqlalchemy.orm import Session
+from sqlalchemy.schema import ForeignKey
 from sqlalchemy.sql.selectable import Exists
 from sqlmodel import Relationship, select
 
@@ -24,55 +25,124 @@ class CreateTimeMixin(SQLModel):
     create_time: datetime = Field(default_factory=datetime.now, title=_("Create Time"))
 
 
-class UsernameMixin(SQLModel):
-    username: str = Field(
-        title=_("Username"), max_length=32, sa_column=Column(String(32), unique=True, index=True, nullable=False)
+class UpdateTimeMixin(SQLModel):
+    update_time: Optional[datetime] = Field(
+        default_factory=datetime.now,
+        title=_("Update Time"),
+        sa_column_kwargs={"onupdate": func.now(), "server_default": func.now()},
     )
 
 
+class UsernameMixin(SQLModel):
+    username: str = Field(title=_("Username"), max_length=32, unique=True, index=True, nullable=False)
+
+
 class PasswordStr(SecretStr, str):
     pass
 
 
 class PasswordMixin(SQLModel):
-    password: PasswordStr = Field(
-        title=_("Password"), max_length=128, sa_column=Column(String(128), nullable=False), amis_form_item="input-password"
-    )
+    password: PasswordStr = Field(title=_("Password"), max_length=128, nullable=False, amis_form_item="input-password")
 
 
 class EmailMixin(SQLModel):
-    email: EmailStr = Field(
-        None, title=_("Email"), sa_column=Column(String(50), unique=True, index=True, nullable=True), amis_form_item="input-email"
-    )
+    """If you need to define the email field as unique, you can achieve it by adding the following parameters in the subclass:
+    __table_args__ = (UniqueConstraint("email", name="email"),)
+    """
+
+    email: EmailStr = Field(None, title=_("Email"), index=True, nullable=True, amis_form_item="input-email")
 
 
 class UserRoleLink(SQLModel, table=True):
     __tablename__ = "auth_user_roles"
-    user_id: Optional[int] = Field(default=None, foreign_key="auth_user.id", primary_key=True, nullable=False)
-    role_id: Optional[int] = Field(default=None, foreign_key="auth_role.id", primary_key=True, nullable=False)
+    user_id: int = Field(
+        primary_key=True,
+        sa_column_args=(
+            ForeignKey(
+                "auth_user.id",
+                ondelete="CASCADE",
+            ),
+        ),
+    )
+    role_id: int = Field(
+        primary_key=True,
+        sa_column_args=(
+            ForeignKey(
+                "auth_role.id",
+                ondelete="CASCADE",
+            ),
+        ),
+    )
 
 
 class UserGroupLink(SQLModel, table=True):
     __tablename__ = "auth_user_groups"
-    user_id: Optional[int] = Field(default=None, foreign_key="auth_user.id", primary_key=True, nullable=False)
-    group_id: Optional[int] = Field(default=None, foreign_key="auth_group.id", primary_key=True, nullable=False)
+    user_id: int = Field(
+        primary_key=True,
+        sa_column_args=(
+            ForeignKey(
+                "auth_user.id",
+                ondelete="CASCADE",
+            ),
+        ),
+    )
+    group_id: int = Field(
+        primary_key=True,
+        sa_column_args=(
+            ForeignKey(
+                "auth_group.id",
+                ondelete="CASCADE",
+            ),
+        ),
+    )
 
 
 class GroupRoleLink(SQLModel, table=True):
     __tablename__ = "auth_group_roles"
-    group_id: Optional[int] = Field(default=None, foreign_key="auth_group.id", primary_key=True, nullable=False)
-    role_id: Optional[int] = Field(default=None, foreign_key="auth_role.id", primary_key=True, nullable=False)
+    group_id: int = Field(
+        primary_key=True,
+        sa_column_args=(
+            ForeignKey(
+                "auth_group.id",
+                ondelete="CASCADE",
+            ),
+        ),
+    )
+    role_id: int = Field(
+        primary_key=True,
+        sa_column_args=(
+            ForeignKey(
+                "auth_role.id",
+                ondelete="CASCADE",
+            ),
+        ),
+    )
 
 
 class RolePermissionLink(SQLModel, table=True):
     __tablename__ = "auth_role_permissions"
-    role_id: Optional[int] = Field(default=None, foreign_key="auth_role.id", primary_key=True, nullable=False)
-    permission_id: Optional[int] = Field(default=None, foreign_key="auth_permission.id", primary_key=True, nullable=False)
+    role_id: int = Field(
+        primary_key=True,
+        sa_column_args=(
+            ForeignKey(
+                "auth_role.id",
+                ondelete="CASCADE",
+            ),
+        ),
+    )
+    permission_id: int = Field(
+        primary_key=True,
+        sa_column_args=(
+            ForeignKey(
+                "auth_permission.id",
+                ondelete="CASCADE",
+            ),
+        ),
+    )
 
 
 class BaseUser(PkMixin, UsernameMixin, PasswordMixin, EmailMixin, CreateTimeMixin):
     __tablename__ = "auth_user"
-    __table_args__ = {"extend_existing": True}
     is_active: bool = Field(default=True, title=_("Is Active"))
     nickname: str = Field(None, title=_("Nickname"), max_length=40)
     avatar: str = Field(
@@ -193,9 +263,7 @@ class User(BaseUser, table=True):
 
 class BaseRBAC(PkMixin):
     __table_args__ = {"extend_existing": True}
-    key: str = Field(
-        ..., title=_("Identify"), max_length=20, sa_column=Column(String(20), unique=True, index=True, nullable=False)
-    )
+    key: str = Field(..., title=_("Identify"), max_length=20, unique=True, index=True, nullable=False)
     name: str = Field(..., title=_("Name"), max_length=20)
     desc: str = Field(default="", title=_("Description"), max_length=400, amis_form_item="textarea")
 
@@ -210,7 +278,16 @@ class Role(BaseRBAC, table=True):
 
 class BaseGroup(BaseRBAC):
     __tablename__ = "auth_group"
-    parent_id: int = Field(None, title=_("Parent"), foreign_key="auth_group.id")
+    parent_id: Optional[int] = Field(
+        None,
+        title=_("Parent"),
+        sa_column_args=(
+            ForeignKey(
+                "auth_group.id",
+                ondelete="SET NULL",
+            ),
+        ),
+    )
 
 
 class Group(BaseGroup, table=True):
